abacusai.feature_drift_summary — AbacusAI documentation

# abacusai.feature_drift_summary

## Classes

`CategoricalRangeViolation` | Summary of important range mismatches for a numerical feature discovered by a model monitoring instance
`NullViolation` | Summary of anomalous null frequencies for a feature discovered by a model monitoring instance
`RangeViolation` | Summary of important range mismatches for a numerical feature discovered by a model monitoring instance
`AbstractApiClass` |
`FeatureDriftSummary` | Summary of important model monitoring statistics for features available in a model monitoring instance

## Module Contents

class abacusai.feature_drift_summary.CategoricalRangeViolation(client, name=None, mostCommonValues=None, freqOutsideTrainingRange=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of important range mismatches for a numerical feature discovered by a model monitoring instance

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – Name of feature.

    - mostCommonValues (list[str]) – List of most common feature names in the prediction distribution not present in the training distribution.

    - freqOutsideTrainingRange (float) – Frequency of prediction rows outside training distribution for the specified feature.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.feature_drift_summary.NullViolation(client, name=None, violation=None, trainingNullFreq=None, predictionNullFreq=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of anomalous null frequencies for a feature discovered by a model monitoring instance

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – Name of feature.

    - violation (str) – Description of null violation for a prediction feature.

    - trainingNullFreq (float) – Proportion of null entries in training feature.

    - predictionNullFreq (float) – Proportion of null entries in prediction feature.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.feature_drift_summary.RangeViolation(client, name=None, trainingMin=None, trainingMax=None, predictionMin=None, predictionMax=None, freqAboveTrainingRange=None, freqBelowTrainingRange=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of important range mismatches for a numerical feature discovered by a model monitoring instance

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – Name of feature.

    - trainingMin (float) – Minimum value of training distribution for the specified feature.

    - trainingMax (float) – Maximum value of training distribution for the specified feature.

    - predictionMin (float) – Minimum value of prediction distribution for the specified feature.

    - predictionMax (float) – Maximum value of prediction distribution for the specified feature.

    - freqAboveTrainingRange (float) – Frequency of prediction rows below training minimum for the specified feature.

    - freqBelowTrainingRange (float) – Frequency of prediction rows above training maximum for the specified feature.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.feature_drift_summary.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.feature_drift_summary.FeatureDriftSummary(client, featureIndex=None, name=None, distance=None, jsDistance=None, wsDistance=None, ksStatistic=None, predictionDrift=None, targetColumn=None, dataIntegrityTimeseries=None, nestedSummary=None, psi=None, csi=None, chiSquare=None, nullViolations={}, rangeViolations={}, catViolations={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of important model monitoring statistics for features available in a model monitoring instance

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureIndex (list[dict]) – A list of dicts of eligible feature names and corresponding overall feature drift measures.

    - name (str) – Name of feature.

    - distance (float) – Symmetric sum of KL divergences between the training distribution and the range of values in the specified window.

    - jsDistance (float) – JS divergence between the training distribution and the range of values in the specified window.

    - wsDistance (float) – Wasserstein distance between the training distribution and the range of values in the specified window.

    - ksStatistic (float) – Kolmogorov-Smirnov statistic computed between the training distribution and the range of values in the specified window.

    - predictionDrift (float) – Drift for the target column.

    - targetColumn (str) – Target column name.

    - dataIntegrityTimeseries (dict) – Frequency vs Data Integrity Violation Charts.

    - nestedSummary (list[dict]) – Summary of model monitoring statistics for nested features.

    - psi (float) – Population stability index computed between the training distribution and the range of values in the specified window.

    - csi (float) – Characteristic Stability Index computed between the training distribution and the range of values in the specified window.

    - chiSquare (float) – Chi-square statistic computed between the training distribution and the range of values in the specified window.

    - nullViolations (NullViolation) – A list of dicts of feature names and a description of corresponding null violations.

    - rangeViolations (RangeViolation) – A list of dicts of numerical feature names and corresponding prediction range discrepancies.

    - catViolations (CategoricalRangeViolation) – A list of dicts of categorical feature names and corresponding prediction range discrepancies.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict